# pandas_ext
Python Pandas extensions for pandas dataframes


# Usage

```
import pandas_ext as px

px.read_csv
px.to_csv

px.read_gdrive
px.to_gdrive

px.read_parquet
px.to_parquet

px.to_spectrum

px.read_sfdc
px.sfdc_metadata
px.patch_sfdc
px.async_patch_sfdc

px.read_sql
px.list_backends

px.to_xml
```
